@@ -1,5 +1,5 @@
 /* evilwm - Minimalist Window Manager for X
- * Copyright (C) 1999-2011 Ciaran Anscomb <evilwm@6809.org.uk>
+ * Copyright (C) 1999-2015 Ciaran Anscomb <evilwm@6809.org.uk>
  * see README for license and other details. */
 
 #include <stdint.h>
@@ -161,14 +161,14 @@ void make_new_client(Window w, ScreenInfo *s) {
 	{
 		client_show(c);
 		client_raise(c);
-#ifndef MOUSE
-		select_client(c);
+		if (!(window_type & (EWMH_WINDOW_TYPE_DOCK|EWMH_WINDOW_TYPE_NOTIFICATION))) {
+			select_client(c);
 #ifdef WARP_POINTER
-		setmouse(c->window, c->width + c->border - 1,
-				c->height + c->border - 1);
-#endif
-		discard_enter_events(c);
+			setmouse(c->window, c->width + c->border - 1,
+				 c->height + c->border - 1);
 #endif
+			discard_enter_events(c);
+		}
 	}
 #ifdef VWM
 	else {
@@ -255,16 +255,12 @@ static void init_geometry(Client *c) {
 		c->x = attr.x;
 		c->y = attr.y;
 	} else {
-#ifdef MOUSE
 		int xmax = DisplayWidth(dpy, c->screen->screen);
 		int ymax = DisplayHeight(dpy, c->screen->screen);
 		int x, y;
 		get_mouse_position(&x, &y, c->screen->root);
 		c->x = (x * (xmax - c->border - c->width)) / xmax;
 		c->y = (y * (ymax - c->border - c->height)) / ymax;
-#else
-		c->x = c->y = 0;
-#endif
 		send_config(c);
 	}
 
@@ -295,10 +291,8 @@ static void reparent(Client *c) {
 	XSetWindowBorderWidth(dpy, c->window, 0);
 	XReparentWindow(dpy, c->window, c->parent, 0, 0);
 	XMapWindow(dpy, c->window);
-#ifdef MOUSE
 	grab_button(c->parent, grabmask2, AnyButton);
 	grab_button(c->parent, grabmask2 | altmask, AnyButton);
-#endif
 }
 
 /* Get WM_NORMAL_HINTS property */
